@@ -1,11 +1,17 @@
-from pydantic import BaseModel, Field
+from enum import Enum
 
-from common_py.workflow.nodes.fields import FieldFormat
+from pydantic import BaseModel, Field
 
 from .. import enums
 from . import ToolOutput
 
 
+class FieldFormat(str, Enum):
+    COMMA_SEPARATED_LIST = "comma-separated-list"
+    JINJA_TEMPLATE = "jinja-template"
+    DEFAULT = "default"
+
+
 # TODO: this tool probably needs to be replaced by something that reads only a single
 # datasource at a time, or takes in a list of datasource IDs.
 class ReadDatasourcesInput(BaseModel):
