@@ -13,6 +13,7 @@ from . import (
     file,
     firecrawl,
     folder,
+    gmail,
     google,
     llm,
     nl_to_sql,
@@ -48,6 +49,7 @@ __all__ = [
     "firecrawl",
     "folder",
     "google",
+    "gmail",
     "llm",
     "nl_to_sql",
     "operators",
