@@ -6,7 +6,6 @@ from ..models.tools.clinical_trials_search_models import (
     ClinicalTrialsSearchInput,
     ClinicalTrialsSearchOutput,
     ClinicalTrialsSearchResponse,
-    ToolSummary,
 )
 
 __all__ = [
@@ -15,7 +14,6 @@ __all__ = [
     "ClinicalTrialsSearchInput",
     "ClinicalTrialsSearchOutput",
     "ClinicalTrialsSearchResponse",
-    "ToolSummary",
     "clinical_trials_search",
 ]
 
